%define build_external_fuse 0
%define build_external_fuse 1

# flag to allow local users to mount partitions. This is *really* not a good
# idea, because all users who have access to the device can do whatever they
# want with the data, and it also adds a root setuid binary to your system, so
# use it on your own risk. Refer to
# http://www.tuxera.com/community/ntfs-3g-faq/#useroption for details.
%define allow_unsafe_mount 0
%if %allow_unsafe_mount
# user mount only works if ntfs-3g is using internal fuse library
%define build_external_fuse 0
%endif

%define major	88
%define libname %mklibname %{name} %{major}
%define develname %mklibname %{name} -d

Name:		ntfs-3g
Version:	2017.3.23
Release:	%mkrel 3
Summary:	Read-write ntfs driver
License:	GPLv2+
Group:		System/Base
URL:		http://www.tuxera.com/community/open-source-ntfs-3g/
Source0:	http://tuxera.com/opensource/%{name}_ntfsprogs-%{version}.tgz
Patch0:		ntfs-3g_ntfsprogs-2011.10.9-RC-ntfsck-unsupported-return-0.patch
#Allow reading Windows 10 CU written partitions
Patch1:         ntfs-3g-check-mftmirr.patch

BuildRequires:	attr-devel
BuildRequires:	libgcrypt-devel
BuildRequires:	pkgconfig(gnutls)
%if %build_external_fuse
BuildRequires:	pkgconfig(fuse) >= 2.8
Requires:	fuse >= 2.8
Requires(pre):	fuse >= 2.8
%else
Requires:	kmod(fuse)
%endif
Obsoletes:	ntfsprogs < 2.0.0-11
Provides:	ntfsprogs = %{version}-%{release}

%description
The ntfs-3g package contains NTFS filesystem driver with read and
write support. It provides safe and fast handling of MS Windows Vista,
XP, 2000 and Server 2003 NTFS file systems. Most POSIX file system
operations are supported.

%package	-n %{libname}
Summary:	Library for ntfs-3g
Group:		System/Libraries
Conflicts:	%{name} < 2017.3.23-2

%description	-n %{libname}
This package contains the library needed to run programs dynamically
linked with libntfs-3g.

%package	-n %{develname}
Summary:	Headers and static libraries for ntfs-3g
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Obsoletes:	%{_lib}ntfs-devel < 2.0.0-11
Obsoletes:	ntfs-3g-devel < 2017.3.23-2

%description	-n %{develname}
You should install this package if you wish to develop applications that
use ntfs-3g.

%prep
%setup -qn %{name}_ntfsprogs-%{version}
%autopatch -p1

%build
export CFLAGS="%{optflags} -fPIC"
%configure2_5x \
	--disable-static \
	--exec-prefix=/ \
	--bindir=/bin \
	--libdir=/%{_lib} \
	--sbindir=/sbin \
	--disable-ldconfig \
	--enable-crypto \
	--enable-extras \
%if %build_external_fuse
	--with-fuse=external
%else
	--with-fuse=internal
%endif
%make_build

%install
sed -i -e 's|/sbin/ldconfig|true|' src/Makefile
%make_install

# make the symlink an actual copy to avoid confusion
rm -rf %{buildroot}/sbin/mount.ntfs-3g
cp -a %{buildroot}/bin/ntfs-3g %{buildroot}/sbin/mount.ntfs-3g
ln -sf /sbin/mount.ntfs-3g %{buildroot}/sbin/mount.ntfs
ln -sf /sbin/mount.ntfs-3g %{buildroot}/sbin/mount.ntfs-fuse
mkdir -p %{buildroot}%{_bindir}
ln -sf /sbin/mount.ntfs-3g %{buildroot}%{_bindir}/ntfsmount

# .pc file should always be there
mkdir -p %{buildroot}%{_libdir}
mv -f %{buildroot}/%{_lib}/pkgconfig %{buildroot}%{_libdir}/pkgconfig

# remove doc files, as we'll cp them later
rm -fr %{buildroot}%{_datadir}/doc %{buildroot}/%{_lib}/*.la


%files
%doc README AUTHORS CREDITS NEWS
%{_bindir}/ntfsmount
/bin/lowntfs-3g
/bin/ntfs-3g
/bin/ntfs-3g.probe
/bin/ntfssecaudit
/bin/ntfsusermap
/bin/ntfscat
/bin/ntfscluster
/bin/ntfscmp
/bin/ntfsdecrypt
/bin/ntfsfix
/bin/ntfsinfo
/bin/ntfsls
/bin/ntfsrecover
/bin/ntfswipe
/bin/ntfstruncate
/sbin/mkfs.ntfs
/sbin/mkntfs
/sbin/ntfsclone
/sbin/ntfscp
/sbin/ntfslabel
/sbin/ntfsresize
/sbin/ntfsundelete
%{_mandir}/man8/*
%if %allow_unsafe_mount
%attr(4755,root,root) /sbin/mount.ntfs-3g
%else
%attr(754,root,root) /sbin/mount.ntfs-3g
%endif
/sbin/mount.ntfs
/sbin/mount.lowntfs-3g
/sbin/mount.ntfs-fuse

%files -n %{libname}
/%{_lib}/libntfs-3g.so.%{major}{,.*}

%files -n %{develname}
%doc ChangeLog
/%{_lib}/libntfs-3g.so
%{_includedir}/ntfs-3g
%{_libdir}/pkgconfig/*.pc


%changelog
* Mon May 21 2018 zezinho <zezinho> 2017.3.23-3.mga6
  (not released yet)
+ Revision: 1231029
- added patch to read Win10cu written partitons
- libify the package to ensure better updates
- try to fix mga#22942

* Fri Feb 03 2017 luigiwalser <luigiwalser> 2016.2.22-4.mga6
+ Revision: 1084635
- add patch to fix CVE-2017-0358

* Mon Mar 21 2016 tv <tv> 2016.2.22-3.mga6
+ Revision: 993635
- adjust file list
- new release

* Tue Jan 12 2016 tv <tv> 2015.3.14-3.mga6
+ Revision: 922266
- rebuild for new gnutls

* Thu Sep 10 2015 fwang <fwang> 2015.3.14-2.mga6
+ Revision: 875429
- rebuild for new libgcrypt

* Sat Aug 15 2015 daviddavid <daviddavid> 2015.3.14-1.mga6
+ Revision: 864887
- new version: 2015.3.14
- add patch from Fedora to fix CVE-2015-3202
- update URL
- enable crypto and extras supports

* Wed Oct 15 2014 umeabot <umeabot> 2014.2.15-4.mga5
+ Revision: 747395
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2014.2.15-3.mga5
+ Revision: 682946
- Mageia 5 Mass Rebuild

* Sun Jun 15 2014 wally <wally> 2014.2.15-2.mga5
+ Revision: 636622
- obsolete also lib and devel pkg from ntfsprogs

* Sat Mar 08 2014 tv <tv> 2014.2.15-1.mga5
+ Revision: 601224
- new release

* Sat Oct 19 2013 umeabot <umeabot> 2013.1.13-3.mga4
+ Revision: 529071
- Mageia 4 Mass Rebuild

* Wed Jul 03 2013 neoclust <neoclust> 2013.1.13-2.mga4
+ Revision: 449888
- apply fixes from upstream for issue with 4K sector drives (bz951603)
  and truncated check for Interix types on a 32-bit CPU (bz958681)
- fix bug preventing reads on compressed files on windows 8 partitions (bz967301)

* Sun May 26 2013 blino <blino> 2013.1.13-1.mga4
+ Revision: 428262
- 2013.1.13

* Sun Feb 24 2013 neoclust <neoclust> 2012.1.15-3.mga3
+ Revision: 400267
- Fix obsoleting as here %%rename does not work ( reported on irc )
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Jan 23 2012 fwang <fwang> 2012.1.15-1.mga2
+ Revision: 200184
- new vesion 2012.1.15

* Mon Dec 05 2011 fwang <fwang> 2011.4.12-3.mga2
+ Revision: 176807
- drop .la file

* Thu Jun 16 2011 tv <tv> 2011.4.12-2.mga2
+ Revision: 108396
- fix file list
- new release (merged with ntfsprogs)

* Thu Mar 03 2011 eandry <eandry> 2011.1.15-1.mga1
+ Revision: 63460
- New version 2011.1.15
- clean spec
- drop hal stuff

* Sat Jan 15 2011 blino <blino> 2010.10.2-2.mga1
+ Revision: 18785
- remove old ldconfig scriptlets and build conditionals
- imported package ntfs-3g


* Fri Dec 03 2010 Oden Eriksson <oeriksson@mandriva.com> 2010.10.2-2mdv2011.0
+ Revision: 606830
- rebuild

* Mon Oct 04 2010 Funda Wang <fwang@mandriva.org> 2010.10.2-1mdv2011.0
+ Revision: 582800
- New version 2010.10.2

* Mon Aug 09 2010 Funda Wang <fwang@mandriva.org> 2010.8.8-1mdv2011.0
+ Revision: 567843
- update to new version 2010.8.8
- add conflicts on older ntfsprogs

* Sun Jul 11 2010 Funda Wang <fwang@mandriva.org> 2010.5.22-1mdv2011.0
+ Revision: 550636
- New version 2010.5.22

* Mon May 17 2010 Eugeni Dodonov <eugeni@mandriva.com> 2010.5.16-1mdv2011.0
+ Revision: 544955
- Updated to 2010.5.16.

* Tue Mar 30 2010 Eugeni Dodonov <eugeni@mandriva.com> 2010.3.6-3mdv2010.1
+ Revision: 529725
- Add a flag to allow enabling user mounts (#45476).

* Mon Mar 15 2010 Eugeni Dodonov <eugeni@mandriva.com> 2010.3.6-2mdv2010.1
+ Revision: 519941
- Provide mount.ntfs, mount.ntfs-fuse and ntfsmount.

* Tue Mar 09 2010 Funda Wang <fwang@mandriva.org> 2010.3.6-1mdv2010.1
+ Revision: 516823
- New version 2010.3.6
- update desc

* Mon Jan 18 2010 Funda Wang <fwang@mandriva.org> 2010.1.16-2mdv2010.1
+ Revision: 493078
- use root group rather than fuse (bug#57113)

* Mon Jan 18 2010 Funda Wang <fwang@mandriva.org> 2010.1.16-1mdv2010.1
+ Revision: 492931
- New version 2010.1.16
- update url

* Mon Nov 16 2009 Funda Wang <fwang@mandriva.org> 2009.11.14-1mdv2010.1
+ Revision: 466631
- fix build
- new version 2009.11.14

* Mon Sep 21 2009 Eugeni Dodonov <eugeni@mandriva.com> 2009.4.4-2mdv2010.0
+ Revision: 446533
- Installing ntfs-3g as default driver for ntfs partitions (#53795).

* Fri Apr 03 2009 Frederic Crozat <fcrozat@mandriva.com> 2009.4.4-1mdv2009.1
+ Revision: 363764
- Release 2009.4.4
- Remove patch1 (fixed upstream)

* Tue Mar 31 2009 Funda Wang <fwang@mandriva.org> 2009.3.8-1mdv2009.1
+ Revision: 362967
- New version 2009.3.8

* Mon Mar 30 2009 Pascal Terjan <pterjan@mandriva.org> 2009.2.1-3mdv2009.1
+ Revision: 362378
- Update /etc/mtab but do not wait for the process

* Fri Mar 27 2009 Pascal Terjan <pterjan@mandriva.org> 2009.2.1-2mdv2009.1
+ Revision: 361736
- Disable mtab updating until a solution for deadlock is found

* Thu Feb 12 2009 Frederik Himpe <fhimpe@mandriva.org> 2009.2.1-1mdv2009.1
+ Revision: 339900
- update to new version 2009.2.1

* Fri Jan 23 2009 Funda Wang <fwang@mandriva.org> 2009.1.1-1mdv2009.1
+ Revision: 332743
- new version 2009.1.1

* Tue Dec 02 2008 Funda Wang <fwang@mandriva.org> 1.5130-1mdv2009.1
+ Revision: 309199
- update to new version 1.5130

* Sun Oct 12 2008 Funda Wang <fwang@mandriva.org> 1.5012-1mdv2009.1
+ Revision: 292619
- New version 1.5012

* Fri Sep 19 2008 Funda Wang <fwang@mandriva.org> 1.2918-1mdv2009.0
+ Revision: 285808
- New version 1.2918

* Sat Aug 16 2008 Funda Wang <fwang@mandriva.org> 1.2812-2mdv2009.0
+ Revision: 272609
- New version 1.2812

* Tue Jul 29 2008 Funda Wang <fwang@mandriva.org> 1.2712-2mdv2009.0
+ Revision: 252183
- fix perms (bug#42306)
- remove incorrect doc dir

* Tue Jul 15 2008 Funda Wang <fwang@mandriva.org> 1.2712-1mdv2009.0
+ Revision: 235723
- New version 1.2712
- use internal fuse even in cooker, as external dependency requires fuse 2.8

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Thu May 29 2008 Funda Wang <fwang@mandriva.org> 1.2531-1mdv2009.0
+ Revision: 213061
- New version 1.2531

* Wed May 07 2008 Funda Wang <fwang@mandriva.org> 1.2506-1mdv2009.0
+ Revision: 202735
- New version 1.2506

* Tue Apr 15 2008 Funda Wang <fwang@mandriva.org> 1.2412-1mdv2009.0
+ Revision: 193607
- New version 1.2412
- obsoletes libntfs-3g, as it produces too many libmajor, and it is not used by other packages
- New version 1.2310
- add fedora patch to fix rhbug#403291 (ignore -n option)

* Mon Feb 18 2008 Funda Wang <fwang@mandriva.org> 1.2216-1mdv2008.1
+ Revision: 171456
- New version 1.2216

* Fri Feb 08 2008 Funda Wang <fwang@mandriva.org> 1.2129-4mdv2008.1
+ Revision: 164013
- move prefix from /usr to /, which solve the problems if
  /usr is not mounted at boot time.

* Fri Feb 01 2008 Funda Wang <fwang@mandriva.org> 1.2129-3mdv2008.1
+ Revision: 161148
- mount.ntfs-3g should be in /sbin rather thatn /usr/sbin (bug#37352)

* Tue Jan 29 2008 Funda Wang <fwang@mandriva.org> 1.2129-2mdv2008.1
+ Revision: 159884
- fuse is not required for old distro
- add conditional building for fuse

* Tue Jan 29 2008 Funda Wang <fwang@mandriva.org> 1.2129-1mdv2008.1
+ Revision: 159810
- New version 1.2129

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Tue Nov 20 2007 Funda Wang <fwang@mandriva.org> 1.1120-1mdv2008.1
+ Revision: 110711
- New version 1.1104
- New major ( 14-> 16 )

* Tue Nov 06 2007 Funda Wang <fwang@mandriva.org> 1.1104-2mdv2008.1
+ Revision: 106394
- rebuild for new lzma

* Mon Nov 05 2007 Funda Wang <fwang@mandriva.org> 1.1104-1mdv2008.1
+ Revision: 106003
- New version 1.1104

* Thu Nov 01 2007 Funda Wang <fwang@mandriva.org> 1.1030-1mdv2008.1
+ Revision: 104318
- New version 1.1030
- New major ( 13 -> 14 )

* Sun Oct 14 2007 Funda Wang <fwang@mandriva.org> 1.1004-2mdv2008.1
+ Revision: 98262
- drop README.install.urpmi, as our kernel is new enough

* Tue Oct 09 2007 Funda Wang <fwang@mandriva.org> 1.1004-1mdv2008.1
+ Revision: 96173
- New major
- New version 1.1004

* Thu Aug 30 2007 Funda Wang <fwang@mandriva.org> 1.826-1mdv2008.0
+ Revision: 75140
- New major
- New version 1.826

* Sun Aug 12 2007 Funda Wang <fwang@mandriva.org> 1.810-1mdv2008.0
+ Revision: 62256
- new major
- New version 1.810

* Thu Jul 26 2007 Helio Chissini de Castro <helio@mandriva.com> 1.710-2mdv2008.0
+ Revision: 56065
- Elegant solution from ArchLinux to enable hal backends to use ntfs-3g instead of standard ntfs
  driver. KDE now mount external and local ntfs storage devices rw by default as long ntfs-3f is
  installed. gnome-mount is not affected, as use different strategy.

  + Götz Waschk <waschk@mandriva.org>
    - fix doc file listing

* Mon Jul 16 2007 Götz Waschk <waschk@mandriva.org> 1.710-1mdv2008.0
+ Revision: 52424
- new version
- rename devel package

* Sun Jun 24 2007 Per Øyvind Karlsen <peroyvind@mandriva.org> 1.616-1mdv2008.0
+ Revision: 43669
- new version: 1.616
- new major

* Fri May 25 2007 Per Øyvind Karlsen <peroyvind@mandriva.org> 1.516-1mdv2008.0
+ Revision: 31052
- build on all architectures (worked just fine on my sparc :)
- new release: 1.516
  new major
  add url to source


* Thu Feb 22 2007 Götz Waschk <waschk@mandriva.org> 1.0-2mdv2007.0
+ Revision: 124370
- fix description
- fix group
- add warning about FUSE version

  + Frederic Crozat <fcrozat@mandriva.com>
    - Fix description

* Wed Feb 21 2007 Götz Waschk <waschk@mandriva.org> 1.0-1mdv2007.1
+ Revision: 123213
- new version
- fix build
- remove warning at installation, this isn't considered beta anymore

  + Thierry Vignaud <tvignaud@mandriva.com>
    - new URL

  + Jérôme Soyer <saispo@mandriva.org>
    - Import ntfs-3g

* Tue Sep 26 2006 Couriousous <couriousous@mandriva.org> 0.1-0.20070920.1mdv2007.0
- 20070920-BETA

* Fri Jul 21 2006 Couriousous <couriousous@mandriva.org> 0.1-0.20070714.2mdv2007.0
- Some spec cleanup
- Build only on ix86
- Upload to contrib

* Thu Jul 20 2006 Davide Duina <davide.duina_AT_gmail_DOT_com> 0.1-0.20070714.1mdv2007.0
- First version, based on Beta 20070714

